pub struct LoaderConfig {
pub channel_capacity: usize,
pub batch_size: usize,
pub continue_on_sink_error: bool,
}Expand description
Configuration for the data loader.
Fields
channel_capacity: usizeSize of the bounded channel between source and fan-out task. Default: 4096.
batch_size: usizeMaximum events per batch (for future batching logic). Default: 256.
continue_on_sink_error: boolIf true, the loader continues even if a sink rejects events.
Default: false.